@@ -56,133 +56,6 @@ const gchar* date_formats[] =
   "wdgt_va_date_long",
 };
 
-void 
-add_time_out_handler(DateTodayPlugin *desktop_plugin);
-
-gboolean
-date_today_update_day(gpointer data)
-{
-  DateTodayPlugin* desktop_plugin = DATE_TODAY_PLUGIN(data);
-  time_t time = time_get_time();
-  struct tm* date_time = localtime(&time);
-  gchar date_buf[256];
-  strftime(date_buf, 255, dgettext("hildon-libs", date_formats[desktop_plugin->date_format]), date_time);
-  if(desktop_plugin->today_string)
-    g_free(desktop_plugin->today_string);
-  desktop_plugin->today_string = g_strdup(date_buf);
-  gtk_widget_queue_draw(desktop_plugin->content);
-  add_time_out_handler(desktop_plugin);
-  return FALSE;
-}
-
-void 
-add_time_out_handler(DateTodayPlugin *desktop_plugin)
-{
-  const time_t current_time = time(NULL);
-  struct tm *local_time;
-  local_time = localtime(&current_time);
-  int diff = 24 - local_time->tm_hour;
-  diff = diff * 60 * 60 - 60*local_time->tm_min - local_time->tm_sec;
-
-  if(desktop_plugin->time_out_handler)
-    g_source_remove(desktop_plugin->time_out_handler);
-
-  desktop_plugin->time_out_handler = g_timeout_add_seconds(diff, 
-							   date_today_update_day, 
-							   (gpointer) desktop_plugin);
-}
-
-void 
-remove_time_out_handler(DateTodayPlugin *desktop_plugin)
-{
-  g_source_remove(desktop_plugin->time_out_handler);
-  desktop_plugin->time_out_handler = 0;  
-}
-
-static GtkWidget*
-build_ui()
-{
-  GtkVBox *contents = GTK_VBOX(gtk_vbox_new(0, FALSE));
-  gtk_widget_show_all(GTK_WIDGET(contents));
-  gtk_widget_add_events(GTK_WIDGET(contents), GDK_BUTTON_PRESS_MASK);
-  return GTK_WIDGET(contents);
-}
-
-static void
-date_today_on_current_desktop(GtkWidget* widget,
-			      gpointer data)
-{
-  DateTodayPlugin *desktop_plugin = DATE_TODAY_PLUGIN(widget);
-  gboolean on;
-  g_object_get(widget, "is-on-current-desktop", &on, NULL);
-  if(on)
-    {
-      date_today_update_day(desktop_plugin);
-    }
-  if(on && !desktop_plugin->time_out_handler)
-    {
-      add_time_out_handler(desktop_plugin);
-      return;
-    }
-  if(!on && desktop_plugin->time_out_handler)
-    {
-      remove_time_out_handler(desktop_plugin);
-    }
-}
-
-static DBusHandlerResult
-handle_time_change(DBusConnection *bus, DBusMessage *msg, gpointer data)
-{
-  date_today_update_day(data);
-  return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
-}
-
-void
-save_settings(DateTodayPlugin* desktop_plugin)
-{
-  GKeyFile *keyFile;
-  gchar *fileData;
-  FILE *iniFile;
-  gsize size;
-  gchar *filename;
-
-  keyFile = g_key_file_new();
-  filename = g_strconcat (HOME_DIR, DATE_TODAY_SETTINGS_FILE, NULL);
-  g_key_file_load_from_file (keyFile, filename, G_KEY_FILE_KEEP_COMMENTS, NULL);
-
-  g_key_file_set_integer(keyFile, desktop_plugin->iD, "launchView", desktop_plugin->launch_view);
-  g_key_file_set_integer(keyFile, desktop_plugin->iD, "size", desktop_plugin->size);
-  g_key_file_set_integer(keyFile, desktop_plugin->iD, "date_format", desktop_plugin->date_format);
-
-  fileData = g_key_file_to_data (keyFile, &size, NULL);
-
-  g_file_set_contents(filename, fileData, size, NULL);
-  g_key_file_free (keyFile);
-  g_free (fileData);
-  g_free (filename);
-}
-
-static GtkListStore*
-_create_format_list(DateTodayPlugin* desktop_plugin)
-{
-  GtkListStore* list_store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
-  GtkTreeIter iter;
-  gchar date_buf[256];
-  time_t time = time_get_time();
-  struct tm* date_time = localtime(&time);
-  int i = 0;
-  for(i = 0; i<12;++i)
-  {
-    strftime(date_buf, 255, dgettext("hildon-libs", date_formats[i]), date_time);
-    gtk_list_store_append(list_store, &iter);
-    gtk_list_store_set(list_store, &iter,
-		       0, date_buf,
-		       1, i,
-		       -1);
-  }
-  return list_store;
-}
-
 static void
 _load_and_render_background_pixbuf(DateTodayPlugin* desktop_plugin)
 {
@@ -245,6 +118,95 @@ _load_and_render_background_pixbuf(DateTodayPlugin* desktop_plugin)
   desktop_plugin->background_pixbuf = pixbuf;
 }
 
+gboolean
+date_today_update_day(gpointer data)
+{
+  DateTodayPlugin* desktop_plugin = DATE_TODAY_PLUGIN(data);
+  time_t time = time_get_time();
+  struct tm* date_time = localtime(&time);
+  int date_day = date_time->tm_mday;
+  if(date_day != desktop_plugin->current_day)
+  {
+    desktop_plugin->current_day = date_day;
+    gchar date_buf[256];
+    strftime(date_buf, 255, dgettext("hildon-libs", date_formats[desktop_plugin->date_format]), date_time);
+    if(desktop_plugin->today_string)
+      g_free(desktop_plugin->today_string);
+    desktop_plugin->today_string = g_strdup(date_buf);
+    _load_and_render_background_pixbuf(desktop_plugin);
+    gtk_widget_queue_draw(desktop_plugin->content);
+    return FALSE;
+  }
+}
+
+static GtkWidget*
+build_ui()
+{
+  GtkVBox *contents = GTK_VBOX(gtk_vbox_new(0, FALSE));
+  gtk_widget_show_all(GTK_WIDGET(contents));
+  gtk_widget_add_events(GTK_WIDGET(contents), GDK_BUTTON_PRESS_MASK);
+  return GTK_WIDGET(contents);
+}
+
+static void
+date_today_on_current_desktop(GtkWidget* widget,
+			      gpointer data)
+{
+  DateTodayPlugin *desktop_plugin = DATE_TODAY_PLUGIN(widget);
+  gboolean on;
+  g_object_get(widget, "is-on-current-desktop", &on, NULL);
+  if(on)
+  {
+    date_today_update_day(desktop_plugin);
+  }
+}
+
+void
+save_settings(DateTodayPlugin* desktop_plugin)
+{
+  GKeyFile *keyFile;
+  gchar *fileData;
+  FILE *iniFile;
+  gsize size;
+  gchar *filename;
+
+  keyFile = g_key_file_new();
+  filename = g_strconcat (HOME_DIR, DATE_TODAY_SETTINGS_FILE, NULL);
+  g_key_file_load_from_file (keyFile, filename, G_KEY_FILE_KEEP_COMMENTS, NULL);
+
+  g_key_file_set_integer(keyFile, desktop_plugin->iD, "launchView", desktop_plugin->launch_view);
+  g_key_file_set_integer(keyFile, desktop_plugin->iD, "size", desktop_plugin->size);
+  g_key_file_set_integer(keyFile, desktop_plugin->iD, "date_format", desktop_plugin->date_format);
+
+  fileData = g_key_file_to_data (keyFile, &size, NULL);
+
+  g_file_set_contents(filename, fileData, size, NULL);
+  g_key_file_free (keyFile);
+  g_free (fileData);
+  g_free (filename);
+}
+
+static GtkListStore*
+_create_format_list(DateTodayPlugin* desktop_plugin)
+{
+  GtkListStore* list_store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
+  GtkTreeIter iter;
+  gchar date_buf[256];
+  time_t time = time_get_time();
+  struct tm* date_time = localtime(&time);
+  int i = 0;
+  for(i = 0; i<12;++i)
+  {
+    strftime(date_buf, 255, dgettext("hildon-libs", date_formats[i]), date_time);
+    gtk_list_store_append(list_store, &iter);
+    gtk_list_store_set(list_store, &iter,
+		       0, date_buf,
+		       1, i,
+		       -1);
+  }
+  return list_store;
+}
+
 static void
 date_today_show_settings_dialog(GtkWidget* widget, gpointer data)
 {
@@ -325,8 +287,8 @@ date_today_show_settings_dialog(GtkWidget* widget, gpointer data)
     else if(desktop_plugin->sheet_size == 2)
       width = HUGE_SHEET_WIDTH;
     width *= (double)height/SHEET_HEIGHT;
+    desktop_plugin->current_day = 0;
     date_today_update_day(desktop_plugin);
-    _load_and_render_background_pixbuf(desktop_plugin);
 
     gtk_widget_set_size_request(GTK_WIDGET(desktop_plugin), width, height);
     gtk_window_resize(GTK_WINDOW(desktop_plugin),
@@ -379,31 +341,6 @@ read_settings(DateTodayPlugin *desktop_plugin)
   g_free(fileName);
 }
 
-void
-register_dbus_signal_on_time_change(DateTodayPlugin* desktop_plugin)
-{
-  desktop_plugin->dbus_conn = NULL;
-  desktop_plugin->dbus_proxy = NULL;
-  desktop_plugin->dbus_conn = hd_home_plugin_item_get_dbus_g_connection ( &desktop_plugin->hitem, 
-									  DBUS_BUS_SYSTEM, 
-									  NULL );
-
-  if(desktop_plugin->dbus_conn)
-  {
-    desktop_plugin->dbus_proxy = dbus_g_proxy_new_for_name(desktop_plugin->dbus_conn,
-							   CLOCKD_SERVICE,
-							   CLOCKD_PATH,
-							   CLOCKD_INTERFACE);
-    dbus_g_proxy_add_signal(desktop_plugin->dbus_proxy,
-			    CLOCKD_TIME_CHANGED,
-			    G_TYPE_INT, G_TYPE_INVALID );
-    dbus_g_proxy_connect_signal(desktop_plugin->dbus_proxy,
-				CLOCKD_TIME_CHANGED,
-				G_CALLBACK(handle_time_change), desktop_plugin, NULL);
-  }
-
-}
-
 static void
 date_today_plugin_init(DateTodayPlugin *desktop_plugin)
 {
@@ -414,11 +351,12 @@ date_today_plugin_init(DateTodayPlugin *desktop_plugin)
   desktop_plugin->size = 100;
   desktop_plugin->launch_view = 1;
   desktop_plugin->today_string = NULL;
+  desktop_plugin->current_day = 0;
   gtk_container_add(GTK_CONTAINER(desktop_plugin), contents);
   hd_home_plugin_item_set_settings (HD_HOME_PLUGIN_ITEM (desktop_plugin), TRUE);
   g_signal_connect(desktop_plugin, "notify::is-on-current-desktop", G_CALLBACK(date_today_on_current_desktop), NULL);
   g_signal_connect(desktop_plugin, "show-settings", G_CALLBACK(date_today_show_settings_dialog), NULL);
-  register_dbus_signal_on_time_change(desktop_plugin);
+  //  register_dbus_signal_on_time_change(desktop_plugin);
 }
 
 static void
@@ -431,7 +369,6 @@ datetoday_realize(GtkWidget* widget)
   desktop_plugin->iD = hd_home_plugin_item_get_applet_id (HD_HOME_PLUGIN_ITEM (widget));
   read_settings(desktop_plugin);
   date_today_update_day(desktop_plugin);
-  _load_and_render_background_pixbuf(desktop_plugin);
   int width = SHORT_SHEET_WIDTH;
   int height = desktop_plugin->size;
   if(desktop_plugin->sheet_size == 1)
@@ -499,21 +436,12 @@ static void
 date_today_plugin_finalize(GObject *object)
 {
   DateTodayPlugin *desktop_plugin = DATE_TODAY_PLUGIN(object);
-  if(desktop_plugin->time_out_handler)
-  {
-    remove_time_out_handler(desktop_plugin);
-  }
   if(desktop_plugin->today_string)
   {
     g_free(desktop_plugin->today_string);
   }
   g_free(desktop_plugin->iD);
-  if (desktop_plugin->dbus_proxy)
-    dbus_g_proxy_disconnect_signal (desktop_plugin->dbus_proxy, 
-				    CLOCKD_TIME_CHANGED, G_CALLBACK(handle_time_change), desktop_plugin);
-  
   G_OBJECT_CLASS (date_today_plugin_parent_class)->finalize (object);
-
 }
 
 static void
